# Financas

Description. 
The package financas is used to:
		'''
		- Storage information about one's wallet and it's operations
		- Adding Values and Listing based on user's input
		'''

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install financas
```

## Usage

```python
from package_name import file1_name
file1_name.my_function()
```

## Author
André Boechat

## License
[MIT](https://choosealicense.com/licenses/mit/)